@@ -30,6 +30,22 @@ from Products.ATVocabularyManager.tools import registerVocabularyTerm
 from Products.ATVocabularyManager.event import find_toplevel_vocab, TermRenamedEvent
 from Products.ATVocabularyManager.config import PROJECTNAME
 
+term_schema = BaseContent.schema + Schema()
+
+term_schema['id'] = BaseContent.schema['id'].copy()
+term_schema['id'].widget.label = "Key"
+term_schema['id'].widget.label_msgid = "label_key"
+term_schema['id'].widget.description = "Should not contain spaces, underscores or mixed case."
+term_schema['id'].widget.description_msgid = "help_key"
+term_schema['id'].widget.i18n_domain = "atvocabularymanager"
+
+term_schema['title'] = BaseContent.schema['title'].copy()
+term_schema['title'].widget.label = "Value"
+term_schema['title'].widget.label_msgid = "label_value"
+term_schema['title'].widget.i18n_domain = "atvocabularymanager"
+
+
+
 class SimpleVocabularyTerm(BaseContent):
     security = ClassSecurityInfo()
     portal_type = meta_type = 'SimpleVocabularyTerm'
@@ -38,33 +54,7 @@ class SimpleVocabularyTerm(BaseContent):
 
     __implements__ = getattr(BaseContent,'__implements__',()) + (IVocabularyTerm,)
 
-    schema = BaseSchema + Schema((
-        StringField('id',
-            required=0, ## Still actually required, but
-                        ## the widget will supply the missing value
-                        ## on non-submits
-            mode="rw",
-            accessor="getId",
-            mutator="setId",
-            default='',
-            widget=StringWidget(
-                label="Key",
-                label_msgid="label_key",
-                description="Should not contain spaces, underscores or mixed case. ",
-                description_msgid="help_key",
-                i18n_domain="atvocabularymanager"),
-            ),
-        StringField('title',
-            required=1,
-            searchable=0,
-            default='',
-            accessor='Title',
-            widget=StringWidget(
-                label="Value",
-                label_msgid="label_value",
-                i18n_domain="atvocabularymanager"),
-        )),
-    )
+    schema = term_schema
 
     aliases = {
         '(Default)' : 'base_view',
@@ -90,10 +80,11 @@ class SimpleVocabularyTerm(BaseContent):
         if not lang is None:
             # if we ask for a specific language, we try to
             # provide it
-            trans = self.getTranslation(lang)
+            obj = self.getTranslation(lang) or self
             # if not found, we return the title of the current term
-            return trans and trans.Title() or self.Title()
-        return self.Title()
+        else:
+            obj = self
+        return obj.Title().decode('utf8')
 
     def getTermKeyPath(self):
         # terms of flat vocabularies can savely return their key
